aboutsummaryrefslogtreecommitdiff
path: root/lib/util.h
diff options
context:
space:
mode:
authorKitsune Ral <Kitsune-Ral@users.sf.net>2019-03-24 19:09:48 +0900
committerKitsune Ral <Kitsune-Ral@users.sf.net>2019-03-24 19:09:48 +0900
commitadcea5868d45610be0539af3e1cfc15f8495815c (patch)
tree61eac587abf7999ae5e0b40799086364241af185 /lib/util.h
parente2dea5a7e263707c283b63f0c31b4fae8399db3b (diff)
downloadlibquotient-adcea5868d45610be0539af3e1cfc15f8495815c.tar.gz
libquotient-adcea5868d45610be0539af3e1cfc15f8495815c.zip
Expose linkifyUrls() into library API for future use
Diffstat (limited to 'lib/util.h')
-rw-r--r--lib/util.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/lib/util.h b/lib/util.h
index beb3c697..f08c1c95 100644
--- a/lib/util.h
+++ b/lib/util.h
@@ -296,13 +296,16 @@ namespace QMatrixClient
return std::make_pair(last, sLast);
}
+ /** Convert what looks like a URL or a Matrix ID to an HTML hyperlink */
+ void linkifyUrls(QString& htmlEscapedText);
+
/** Sanitize the text before showing in HTML
* This does toHtmlEscaped() and removes Unicode BiDi marks.
*/
QString sanitized(const QString& plainText);
/** Pretty-print plain text into HTML
* This includes HTML escaping of <,>,",& and URLs linkification.
*/
QString prettyPrint(const QString& plainText);
@@ -296,13 +296,16 @@ namespace QMatrixClient
QString sanitized(const QString& plainText);
/** Pretty-print plain text into HTML
- * This includes HTML escaping of <,>,",& and URLs linkification.
+ * This includes HTML escaping of <,>,",& and calling linkifyUrls()
*/
QString prettyPrint(const QString& plainText);